@@ -65,14 +65,21 @@ int main (int argc, char **argv)
 
   if (argdata->dump_info) {
      time_t now = time(NULL);
+     u_int64_t display_blocks_used = 0;
+
      output_info ("");
      output_info ("%s Filesystem blocks quota limit grace files quota limit grace",
 		  argdata->id_type == QUOTA_USER ? "uid" : "gid");
-     
+     //    this is confusing:
+     // 1. quota->block_used should really be called space_used or bytes_used
+     // 2. quota_blocks_used is actually kilobytes used
+     // 3. when dividing by 1024, we need to add one if there's a remainder
+     display_blocks_used = quota->block_used / 1024;
+     if (quota->block_used % 1024 != 0) display_blocks_used += 1;
      printf("%d %s %llu %llu %llu %d %llu %llu %llu %d\n",
 	    id,
 	    argdata->qfile,
-	    quota->block_used / 1024 + 1,
+	    display_blocks_used,
 	    quota->block_soft,
 	    quota->block_hard,
 	    quota->block_time ? quota->block_time - now : 0,
