@@ -3,7 +3,7 @@
  * mpg4@duluoz.net
  *
  * Johan Ekenberg
- * johan@ekenberg.nu
+ * johan@ekenberg.se
  *
  * parse.c
  * command line parsing routines
@@ -18,28 +18,10 @@
 #include <unistd.h>
 
 
-/* FIXME: this is getting to be a mess */
-#if HAVE_LINUX_FS_H
-#  include <linux/version.h>
-#  if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
-#    define BLOCK_SIZE 1024
-#  else
-#    include <linux/fs.h>		
-#  endif
-#elif HAVE_STD_H
-#  include <std.h>
-#  define BLOCK_SIZE MULBSIZE
-#else
-/*#  warn "making up a block size" */
-/* FIXME: "warn" directive does not work with gcc 2.8.1 on aix -cagri*/
-#  define BLOCK_SIZE 1024
-#endif
-
-
+#include "quotatool.h"
 #include "output.h"
 #include "parse.h"
 #include "quota.h"
-#include "quotatool.h"
 #include "system.h"
 
 
@@ -47,9 +29,9 @@
 
 
 #if HAVE_GNU_GETOPT
-#  define OPTSTRING "hVvnu::g::birq:l:t:"
+#  define OPTSTRING "hVvnu::g::birq:l:t:dR"
 #else
-#  define OPTSTRING "hVvnu:g:birq:l:t:"
+#  define OPTSTRING "hVvnu:g:birq:l:t:dR"
 #endif
 
 
@@ -85,16 +67,14 @@ argdata_t *parse_commandline (int argc, char **argv)
   optarg = NULL;
   opterr = 0;
   done = fail = 0;
-  while ( ! done && ! fail ) {
-
-    
+  while ( ! done && ! fail ) {    
     opt = getopt(argc, argv, OPTSTRING);
     
-    output_debug ("option: '%c', argument: '%s'", opt, optarg);
+    if (opt > 0) 
+       output_debug ("option: '%c', argument: '%s'", opt, optarg);
+
     switch (opt) {
 
-
-
     case EOF:
       done = 1;
       break;
@@ -270,7 +250,13 @@ argdata_t *parse_commandline (int argc, char **argv)
       output_info ("resetting grace period");
       break;
 
-      
+    case 'd':
+       data->dump_info = 1;
+       break;
+
+    case 'R':
+       data->raise_only = 1;
+       break;
 
     case ':':
       output_error ("Option '%c' requires an argument", optopt);
@@ -298,6 +284,10 @@ argdata_t *parse_commandline (int argc, char **argv)
     output_error ("Must specify either user or group quota");
     return NULL;
   }
+  
+  if ( data->dump_info) {
+     output_info("Option 'd' => just dumping quota-info for %s", data->id_type == QUOTA_USER ? "user" : "group");
+  }
 
   /* the remaining arg is the filesystem */
   data->qfile = argv[optind];
@@ -403,9 +393,10 @@ time_t parse_timespan (time_t orig, char *string)
  * understands Kb, Mb, bytes, and disk blocks
  * returns the number of bytes represented
  */
-uint parse_size (uint orig, char *string) {
+u_int64_t parse_size (u_int64_t orig, char *string) {
   char *cp;
-  uint count, unit, blocks;
+  u_int64_t blocks;
+  uint count, unit;
   char op;
 
   op = '\0';
@@ -447,7 +438,7 @@ uint parse_size (uint orig, char *string) {
   }
 
   /* calculate disk blocks */
-  blocks = (uint) (((double) count*unit - 1) / BLOCK_SIZE) + 1;
+  blocks = (u_int64_t) (((double) count*unit - 1) / BLOCK_SIZE) + 1;
 
   switch (op) {
   case _PARSE_OP_ADD:
