@@ -3,7 +3,7 @@
  * mpg4@duluoz.net
  *
  * Johan Ekenberg
- * johan@ekenberg.nu
+ * johan@ekenberg.se
  *
  * parse.h
  *
@@ -21,6 +21,8 @@ struct _argdata_t {
   short id_type;
   short silent;
   short noaction;
+  short dump_info; // don't touch anything, just dump machine-readable info for user/group
+  short raise_only; // When changing quotas, don't lower - just raise
 
   char *block_hard;
   char *block_soft;
@@ -37,7 +39,7 @@ typedef struct _argdata_t argdata_t;
 
 argdata_t *   parse_commandline   (int argc, char **argv);
 time_t        parse_timespan      (time_t orig, char *string);
-uint          parse_size          (uint orig, char *string);
+u_int64_t     parse_size          (u_int64_t orig, char *string);
 
 
 #endif /* INCLUDE_QUOTATOOL_PARSE */
