@@ -109,7 +109,7 @@ fs_t *system_getfs (char *fs_spec) {
 #if HAVE_SYS_MNTTAB_H
     int retval;
     retval = getmntent(etc_mtab, current_fs);
-    if ( ! retval ) {
+    if ( retval != 0 ) {
 #elif HAVE_MNTENT_H
     current_fs=getmntent(etc_mtab);
     if ( ! current_fs ) {
@@ -136,6 +136,11 @@ fs_t *system_getfs (char *fs_spec) {
 #if HAVE_MNTENT_H
       #define LOOP_PREFIX "loop="
       char *loopd_start = NULL, *loopd_end = NULL;
+
+      #if PLATFORM_LINUX
+      strncpy(ent->mnt_type, current_fs->mnt_type, PATH_MAX-1);
+      #endif
+
       if ((loopd_start = strstr(current_fs->mnt_opts, LOOP_PREFIX "/")) != NULL) {
 	loopd_start += strlen(LOOP_PREFIX);
 	output_debug("%s looks like a loop device, trying to grok opts: %s",
@@ -159,7 +164,6 @@ fs_t *system_getfs (char *fs_spec) {
       }
       else {
 #endif /* HAVE_MNTENT_H */	
-
       strncpy (ent->device, current_fs->mnt_special, PATH_MAX-1);
       strncpy (ent->mount_pt, current_fs->mnt_mountp, PATH_MAX-1);
 #if HAVE_MNTENT_H
